/*  PME - Planejamento de Merenda

Nome: ATUALIZA_COMENSAL

Descrio:
    Atualiza o nmero de comensais do cardpio a partir da
    tela de elaborao do cardpio.
    Caso o cardpio for especfico, sero atualizados os comensais
    somente daquele cardpio, mas se for um cardpio da central,
    a partir de uma lista a ser informada na tela, o operador informar
    quais as filiais que tero os comensais atualizados.

    P_CDFILCENTPME - Central de Merenda
    P_NRCARDPME    - Nmero do Cardpio
    P_NRLISTA      - N da Lista que contm as Filiais Agregadas
    P_CDSERVFILI   - Servio
    P_CDTIPOCARD   - Tipo de Cardpio
    P_DTINI        - Data inicial.
    P_DTFIN        - Data final.

Criao:
    Matheus Totte - 09/11/2006

*/

IF EXISTS (SELECT NAME FROM SYSOBJECTS
           WHERE  NAME = 'ATUALIZA_COMENSAL' AND TYPE = 'P')
   DROP PROCEDURE ATUALIZA_COMENSAL
GO

CREATE PROCEDURE ATUALIZA_COMENSAL
          @P_CDFILCENTPME VARCHAR(04),
          @P_NRCARDPME    VARCHAR(10),
          @P_NRLISTA      VARCHAR(10),
          @P_CDSERVFILI   VARCHAR(05),
          @P_CDTIPOCARD   VARCHAR(10),
          @P_DTINI        DATETIME,
          @P_DTFIN        DATETIME

AS
   DECLARE @V_QTCOMPMESEG DOUBLE PRECISION;  DECLARE @V_QTCLIPMESEG DOUBLE PRECISION;
   DECLARE @V_QTCOMPMETER DOUBLE PRECISION;  DECLARE @V_QTCLIPMETER DOUBLE PRECISION;
   DECLARE @V_QTCOMPMEQUA DOUBLE PRECISION;  DECLARE @V_QTCLIPMEQUA DOUBLE PRECISION;
   DECLARE @V_QTCOMPMEQUI DOUBLE PRECISION;  DECLARE @V_QTCLIPMEQUI DOUBLE PRECISION;
   DECLARE @V_QTCOMPMESEX DOUBLE PRECISION;  DECLARE @V_QTCLIPMESEX DOUBLE PRECISION;
   DECLARE @V_QTCOMPMESAB DOUBLE PRECISION;  DECLARE @V_QTCLIPMESAB DOUBLE PRECISION;
   DECLARE @V_QTCOMPMEDOM DOUBLE PRECISION;  DECLARE @V_QTCLIPMEDOM DOUBLE PRECISION;
   DECLARE @V_QTCOMPMEFER DOUBLE PRECISION;  DECLARE @V_QTCLIPMEFER DOUBLE PRECISION;

   DECLARE @V_QTFUNPMESEG DOUBLE PRECISION;  DECLARE @V_QTDOAPMESEG DOUBLE PRECISION;
   DECLARE @V_QTFUNPMETER DOUBLE PRECISION;  DECLARE @V_QTDOAPMETER DOUBLE PRECISION;
   DECLARE @V_QTFUNPMEQUA DOUBLE PRECISION;  DECLARE @V_QTDOAPMEQUA DOUBLE PRECISION;
   DECLARE @V_QTFUNPMEQUI DOUBLE PRECISION;  DECLARE @V_QTDOAPMEQUI DOUBLE PRECISION;
   DECLARE @V_QTFUNPMESEX DOUBLE PRECISION;  DECLARE @V_QTDOAPMESEX DOUBLE PRECISION;
   DECLARE @V_QTFUNPMESAB DOUBLE PRECISION;  DECLARE @V_QTDOAPMESAB DOUBLE PRECISION;
   DECLARE @V_QTFUNPMEDOM DOUBLE PRECISION;  DECLARE @V_QTDOAPMEDOM DOUBLE PRECISION;
   DECLARE @V_QTFUNPMEFER DOUBLE PRECISION;  DECLARE @V_QTDOAPMEFER DOUBLE PRECISION;

   DECLARE @V_CDFILIAL_AUX   VARCHAR(04);
   DECLARE @V_DIASEMANA      INT;
   DECLARE @V_COMEN_AUX      INT;

   DECLARE @C_CARDAPIO_CDFILCENTPME  VARCHAR(04);
   DECLARE @C_CARDAPIO_NRCARDPME     VARCHAR(10);
   DECLARE @C_CARDAPIO_NRCARDIAPME   VARCHAR(10);
   DECLARE @C_CARDAPIO_CDSERVFILI    VARCHAR(05);
   DECLARE @C_CARDAPIO_CDFILIAL      VARCHAR(04);
   DECLARE @C_CARDAPIO_DTCARDIAPME   DATETIME;
   DECLARE @C_CARDAPIO_QTCOMESTCPME  DOUBLE PRECISION;
   DECLARE @C_CARDAPIO_CDTIPOCARD    VARCHAR(10);

BEGIN
   SET @V_CDFILIAL_AUX = 'XXXX';

   DECLARE C_CARDAPIO CURSOR FOR
      SELECT
         CD.CDFILCENTPME, CD.NRCARDPME,   CD.NRCARDIAPME,  CD.CDSERVFILI,
         CD.CDFILIAL,     CD.DTCARDIAPME, CD.QTCOMESTCPME, CP.CDTIPOCARD
      FROM
         CARDIAPME CD, CARDAPIOPME CP, LISTA LT
      WHERE
         (CD.CDFILCENTPME = @P_CDFILCENTPME) AND
         (CD.NRCARDPME    = @P_NRCARDPME   ) AND
         (CD.CDSERVFILI   = @P_CDSERVFILI  ) AND
         (LT.NRLISTA      = @P_NRLISTA     ) AND
         (CD.CDFILIAL     = LT.CDLISTA     ) AND
         (CP.CDFILCENTPME = CD.CDFILCENTPME) AND
         (CP.NRCARDPME    = CD.NRCARDPME   ) AND
         (CP.CDTIPOCARD   = @P_CDTIPOCARD  ) AND
         (CD.DTCARDIAPME BETWEEN @P_DTINI AND @P_DTFIN)
      ORDER BY
         CDFILIAL;

   OPEN C_CARDAPIO;
   FETCH NEXT FROM C_CARDAPIO INTO @C_CARDAPIO_CDFILCENTPME,
                                   @C_CARDAPIO_NRCARDPME,
                                   @C_CARDAPIO_NRCARDIAPME,
                                   @C_CARDAPIO_CDSERVFILI,
                                   @C_CARDAPIO_CDFILIAL,
                                   @C_CARDAPIO_DTCARDIAPME,
                                   @C_CARDAPIO_QTCOMESTCPME,
                                   @C_CARDAPIO_CDTIPOCARD;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF (@V_CDFILIAL_AUX <> @C_CARDAPIO_CDFILIAL) BEGIN
         SET @V_COMEN_AUX = NULL;
         SELECT
            @V_QTCOMPMESEG = ISNULL(QTCOMPMESEG, 0), @V_QTCOMPMETER = ISNULL(QTCOMPMETER, 0),
            @V_QTCOMPMEQUA = ISNULL(QTCOMPMEQUA, 0), @V_QTCOMPMEQUI = ISNULL(QTCOMPMEQUI, 0),
            @V_QTCOMPMESEX = ISNULL(QTCOMPMESEX, 0), @V_QTCOMPMESAB = ISNULL(QTCOMPMESAB, 0),
            @V_QTCOMPMEDOM = ISNULL(QTCOMPMEDOM, 0), @V_QTCOMPMEFER = ISNULL(QTCOMPMEFER, 0),
            @V_QTCLIPMESEG = ISNULL(QTCLIPMESEG, 0), @V_QTCLIPMETER = ISNULL(QTCLIPMETER, 0),
            @V_QTCLIPMEQUA = ISNULL(QTCLIPMEQUA, 0), @V_QTCLIPMEQUI = ISNULL(QTCLIPMEQUI, 0),
            @V_QTCLIPMESEX = ISNULL(QTCLIPMESEX, 0), @V_QTCLIPMESAB = ISNULL(QTCLIPMESAB, 0),
            @V_QTCLIPMEDOM = ISNULL(QTCLIPMEDOM, 0), @V_QTCLIPMEFER = ISNULL(QTCLIPMEFER, 0),
            @V_QTFUNPMESEG = ISNULL(QTFUNPMESEG, 0), @V_QTFUNPMETER = ISNULL(QTFUNPMETER, 0),
            @V_QTFUNPMEQUA = ISNULL(QTFUNPMEQUA, 0), @V_QTFUNPMEQUI = ISNULL(QTFUNPMEQUI, 0),
            @V_QTFUNPMESEX = ISNULL(QTFUNPMESEX, 0), @V_QTFUNPMESAB = ISNULL(QTFUNPMESAB, 0),
            @V_QTFUNPMEDOM = ISNULL(QTFUNPMEDOM, 0), @V_QTFUNPMEFER = ISNULL(QTFUNPMEFER, 0),
            @V_QTDOAPMESEG = ISNULL(QTDOAPMESEG, 0), @V_QTDOAPMETER = ISNULL(QTDOAPMETER, 0),
            @V_QTDOAPMEQUA = ISNULL(QTDOAPMEQUA, 0), @V_QTDOAPMEQUI = ISNULL(QTDOAPMEQUI, 0),
            @V_QTDOAPMESEX = ISNULL(QTDOAPMESEX, 0), @V_QTDOAPMESAB = ISNULL(QTDOAPMESAB, 0),
            @V_QTDOAPMEDOM = ISNULL(QTDOAPMEDOM, 0), @V_QTDOAPMEFER = ISNULL(QTDOAPMEFER, 0),
            @V_COMEN_AUX   = 1
         FROM
            COMESERVTCAR
         WHERE
            (CDFILCENTPME = @C_CARDAPIO_CDFILCENTPME) AND
            (CDTIPOCARD   = @C_CARDAPIO_CDTIPOCARD  ) AND
            (CDSERVFILI   = @C_CARDAPIO_CDSERVFILI  ) AND
            (CDFILIAL     = @C_CARDAPIO_CDFILIAL    );

         IF (@V_COMEN_AUX IS NULL) BEGIN
            SET @V_QTCOMPMESEG = 0; SET @V_QTCOMPMETER = 0;
            SET @V_QTCOMPMEQUA = 0; SET @V_QTCOMPMEQUI = 0;
            SET @V_QTCLIPMESEG = 0; SET @V_QTCLIPMETER = 0;
            SET @V_QTCLIPMEQUA = 0; SET @V_QTCLIPMEQUI = 0;
            SET @V_QTFUNPMESEG = 0; SET @V_QTFUNPMETER = 0;
            SET @V_QTFUNPMEQUA = 0; SET @V_QTFUNPMEQUI = 0;
            SET @V_QTDOAPMESEG = 0; SET @V_QTDOAPMETER = 0;
            SET @V_QTDOAPMEQUA = 0; SET @V_QTDOAPMEQUI = 0;
            SET @V_QTCOMPMESEX = 0; SET @V_QTCOMPMESAB = 0;
            SET @V_QTCOMPMEDOM = 0; SET @V_QTCOMPMEFER = 0;
            SET @V_QTCLIPMESEX = 0; SET @V_QTCLIPMESAB = 0;
            SET @V_QTCLIPMEDOM = 0; SET @V_QTCLIPMEFER = 0;
            SET @V_QTFUNPMESEX = 0; SET @V_QTFUNPMESAB = 0;
            SET @V_QTFUNPMEDOM = 0; SET @V_QTFUNPMEFER = 0;
            SET @V_QTDOAPMESEX = 0; SET @V_QTDOAPMESAB = 0;
            SET @V_QTDOAPMEDOM = 0; SET @V_QTDOAPMEFER = 0;
         END;

         SET @V_CDFILIAL_AUX = @C_CARDAPIO_CDFILIAL;
      END;

      SET @V_DIASEMANA = NULL;

      SELECT @V_DIASEMANA = 0
      FROM   FERIFILI
      WHERE  (CDFILIAL   = @C_CARDAPIO_CDFILIAL   ) AND
             (DTFERIFILI = @C_CARDAPIO_DTCARDIAPME);

      IF (@V_DIASEMANA IS NULL) BEGIN
         SET @V_DIASEMANA = DATEPART(W, @C_CARDAPIO_DTCARDIAPME);
      END;

      UPDATE CARDIAPME
      SET
         QTCOMESTCPME = CASE @V_DIASEMANA
                           WHEN 0 THEN @V_QTCLIPMEFER
                           WHEN 1 THEN @V_QTCLIPMEDOM
                           WHEN 2 THEN @V_QTCLIPMESEG
                           WHEN 3 THEN @V_QTCLIPMETER
                           WHEN 4 THEN @V_QTCLIPMEQUA
                           WHEN 5 THEN @V_QTCLIPMEQUI
                           WHEN 6 THEN @V_QTCLIPMESEX
                           ELSE @V_QTCLIPMESAB
                        END +
                        CASE @V_DIASEMANA
                           WHEN 0 THEN @V_QTFUNPMEFER
                           WHEN 1 THEN @V_QTFUNPMEDOM
                           WHEN 2 THEN @V_QTFUNPMESEG
                           WHEN 3 THEN @V_QTFUNPMETER
                           WHEN 4 THEN @V_QTFUNPMEQUA
                           WHEN 5 THEN @V_QTFUNPMEQUI
                           WHEN 6 THEN @V_QTFUNPMESEX
                           ELSE @V_QTFUNPMESAB
                        END +
                        CASE @V_DIASEMANA
                           WHEN 0 THEN @V_QTDOAPMEFER
                           WHEN 1 THEN @V_QTDOAPMEDOM
                           WHEN 2 THEN @V_QTDOAPMESEG
                           WHEN 3 THEN @V_QTDOAPMETER
                           WHEN 4 THEN @V_QTDOAPMEQUA
                           WHEN 5 THEN @V_QTDOAPMEQUI
                           WHEN 6 THEN @V_QTDOAPMESEX
                           ELSE @V_QTDOAPMESAB
                        END,

         QTCLIESTCPME = CASE @V_DIASEMANA
                           WHEN 0 THEN @V_QTCLIPMEFER
                           WHEN 1 THEN @V_QTCLIPMEDOM
                           WHEN 2 THEN @V_QTCLIPMESEG
                           WHEN 3 THEN @V_QTCLIPMETER
                           WHEN 4 THEN @V_QTCLIPMEQUA
                           WHEN 5 THEN @V_QTCLIPMEQUI
                           WHEN 6 THEN @V_QTCLIPMESEX
                           ELSE @V_QTCLIPMESAB
                        END,

         QTFUNESTCPME = CASE @V_DIASEMANA
                           WHEN 0 THEN @V_QTFUNPMEFER
                           WHEN 1 THEN @V_QTFUNPMEDOM
                           WHEN 2 THEN @V_QTFUNPMESEG
                           WHEN 3 THEN @V_QTFUNPMETER
                           WHEN 4 THEN @V_QTFUNPMEQUA
                           WHEN 5 THEN @V_QTFUNPMEQUI
                           WHEN 6 THEN @V_QTFUNPMESEX
                           ELSE @V_QTFUNPMESAB
                        END,

         QTDOAESTCPME = CASE @V_DIASEMANA
                           WHEN 0 THEN @V_QTDOAPMEFER
                           WHEN 1 THEN @V_QTDOAPMEDOM
                           WHEN 2 THEN @V_QTDOAPMESEG
                           WHEN 3 THEN @V_QTDOAPMETER
                           WHEN 4 THEN @V_QTDOAPMEQUA
                           WHEN 5 THEN @V_QTDOAPMEQUI
                           WHEN 6 THEN @V_QTDOAPMESEX
                           ELSE @V_QTDOAPMESAB
                        END
      WHERE
         (CDFILCENTPME = @C_CARDAPIO_CDFILCENTPME) AND
         (NRCARDPME    = @C_CARDAPIO_NRCARDPME   ) AND
         (CDSERVFILI   = @C_CARDAPIO_CDSERVFILI  ) AND
         (CDFILIAL     = @C_CARDAPIO_CDFILIAL    ) AND
         (DTCARDIAPME  = @C_CARDAPIO_DTCARDIAPME );

      FETCH NEXT FROM C_CARDAPIO INTO @C_CARDAPIO_CDFILCENTPME,
                                      @C_CARDAPIO_NRCARDPME,
                                      @C_CARDAPIO_NRCARDIAPME,
                                      @C_CARDAPIO_CDSERVFILI,
                                      @C_CARDAPIO_CDFILIAL,
                                      @C_CARDAPIO_DTCARDIAPME,
                                      @C_CARDAPIO_QTCOMESTCPME,
                                      @C_CARDAPIO_CDTIPOCARD;
   END;
   CLOSE C_CARDAPIO;
   DEALLOCATE C_CARDAPIO;

   UPDATE CARDIAPME
   SET
      QTCOMESTCPME = (SELECT SUM(CD.QTCOMESTCPME)
                      FROM   CARDIAPME CD, CARDAPIOPME CP
                      WHERE
                         (CD.CDFILCENTPME = CARDIAPME.CDFILCENTPME) AND
                         (CD.NRCARDPME    = CARDIAPME.NRCARDPME   ) AND
                         (CD.CDSERVFILI   = CARDIAPME.CDSERVFILI  ) AND
                         (CD.CDFILIAL     <> @P_CDFILCENTPME      ) AND
                         (CP.CDFILCENTPME = CD.CDFILCENTPME       ) AND
                         (CP.NRCARDPME    = CD.NRCARDPME          ) AND
                         (CP.CDTIPOCARD   = @P_CDTIPOCARD         ) AND
                         (CD.DTCARDIAPME  = CARDIAPME.DTCARDIAPME ) AND
                         (CD.IDCARDESPEC  <> 'S')),

      QTCLIESTCPME = (SELECT SUM(CD.QTCLIESTCPME)
                      FROM   CARDIAPME CD, CARDAPIOPME CP
                      WHERE
                         (CD.CDFILCENTPME = CARDIAPME.CDFILCENTPME) AND
                         (CD.NRCARDPME    = CARDIAPME.NRCARDPME   ) AND
                         (CD.CDSERVFILI   = CARDIAPME.CDSERVFILI  ) AND
                         (CD.CDFILIAL     <> @P_CDFILCENTPME      ) AND
                         (CP.CDFILCENTPME = CD.CDFILCENTPME       ) AND
                         (CP.NRCARDPME    = CD.NRCARDPME          ) AND
                         (CP.CDTIPOCARD   = @P_CDTIPOCARD         ) AND
                         (CD.DTCARDIAPME  = CARDIAPME.DTCARDIAPME ) AND
                         (CD.IDCARDESPEC  <> 'S')),

      QTFUNESTCPME = (SELECT SUM(CD.QTFUNESTCPME)
                      FROM   CARDIAPME CD, CARDAPIOPME CP
                      WHERE
                         (CD.CDFILCENTPME = CARDIAPME.CDFILCENTPME) AND
                         (CD.NRCARDPME    = CARDIAPME.NRCARDPME   ) AND
                         (CD.CDSERVFILI   = CARDIAPME.CDSERVFILI  ) AND
                         (CD.CDFILIAL     <> @P_CDFILCENTPME      ) AND
                         (CP.CDFILCENTPME = CD.CDFILCENTPME       ) AND
                         (CP.NRCARDPME    = CD.NRCARDPME          ) AND
                         (CP.CDTIPOCARD   = @P_CDTIPOCARD         ) AND
                         (CD.DTCARDIAPME  = CARDIAPME.DTCARDIAPME ) AND
                         (CD.IDCARDESPEC  <> 'S')),

      QTDOAESTCPME = (SELECT SUM(CD.QTDOAESTCPME)
                      FROM   CARDIAPME CD, CARDAPIOPME CP
                      WHERE
                         (CD.CDFILCENTPME = CARDIAPME.CDFILCENTPME) AND
                         (CD.NRCARDPME    = CARDIAPME.NRCARDPME   ) AND
                         (CD.CDSERVFILI   = CARDIAPME.CDSERVFILI  ) AND
                         (CD.CDFILIAL     <> @P_CDFILCENTPME      ) AND
                         (CP.CDFILCENTPME = CD.CDFILCENTPME       ) AND
                         (CP.NRCARDPME    = CD.NRCARDPME          ) AND
                         (CP.CDTIPOCARD   = @P_CDTIPOCARD         ) AND
                         (CD.DTCARDIAPME  = CARDIAPME.DTCARDIAPME ) AND
                         (CD.IDCARDESPEC  <> 'S'))
   WHERE
      (CARDIAPME.CDFILCENTPME = @P_CDFILCENTPME            ) AND
      (CARDIAPME.NRCARDPME    = @P_NRCARDPME               ) AND
      (CARDIAPME.CDSERVFILI   = @P_CDSERVFILI              ) AND
      (CARDIAPME.CDFILIAL     = CARDIAPME.CDFILCENTPME     ) AND
      (CARDIAPME.DTCARDIAPME  BETWEEN @P_DTINI AND @P_DTFIN);

   DELETE FROM LISTA
   WHERE (NRLISTA = @P_NRLISTA);
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'ATUALIZA_COMENSAL','5.05.015';
GO
