IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE	O.NAME = 'NF_PAULISTA'
    	        AND TYPE = 'P'
	            AND U.UID = O.UID
	            AND U.NAME = USER)
DROP PROCEDURE NF_PAULISTA
GO


CREATE PROCEDURE NF_PAULISTA(
                 @P_NRLISTA        VARCHAR(20),
                 @P_CDEMPRESA      VARCHAR(02),
                 @P_DTINICIAL      DATETIME,
                 @P_DTFINAL        DATETIME,
                 @P_NRSEQARQMAG    VARCHAR(10),
                 @P_LIVROMAG       VARCHAR(10),
                 @P_CDINSCESTA     VARCHAR(16))
AS
   DECLARE  @V_EMPRESA       VARCHAR(4000);
   DECLARE  @V_DADOS_20      VARCHAR(4000);
   DECLARE  @V_DADOS_40      VARCHAR(4000);
   DECLARE  @V_DADOS_50      VARCHAR(4000);
   DECLARE  @V_DADOS_90      VARCHAR(4000);
   DECLARE  @V_SEQMAGNET     NUMERIC(10);
   DECLARE  @V_IDFRETE       VARCHAR(1);
   DECLARE  @V_IDSEGUR       VARCHAR(1);
   DECLARE  @V_IDOUTROS      VARCHAR(1);
   DECLARE  @V_IDDESCO       VARCHAR(1);
   DECLARE  @V_CDIMPOSTRIB   VARCHAR(02);
   DECLARE  @V_IPI           VARCHAR(02);
   DECLARE  @V_ISS           VARCHAR(02);
   DECLARE  @V_ICMS          VARCHAR(02);
   DECLARE  @V_CONTADOR      NUMERIC(11);
   DECLARE  @V_CONT_REG_20   NUMERIC(11);
   DECLARE  @V_CONT_REG_30   NUMERIC(11);
   DECLARE  @V_CONT_REG_40   NUMERIC(11);
   DECLARE  @V_CONT_REG_50   NUMERIC(11);
   DECLARE  @V_CONT_REG_60   NUMERIC(11);
   DECLARE  @V_VALOR         NUMERIC;
   DECLARE  @V_VRDESCONTO    NUMERIC;

   /* VARIAVEL DO CURSOR C_NOTAS */
   DECLARE  @C_NOTAS_ARQUIVO      VARCHAR(4000);
   DECLARE  @C_NOTAS_CDLISTA      VARCHAR(20);
   DECLARE  @C_NOTAS_CDFILIAL     VARCHAR(04);
   DECLARE  @C_NOTAS_NRLANCTONF   VARCHAR(10);
   DECLARE  @C_CORPONF_DADOS30    VARCHAR(4000);
   DECLARE  @C_NOTAS_NRNOTAFISC   VARCHAR(20);

BEGIN

   /* sequencial para gerao da nota fiscal paulista */
   SET @V_CONTADOR    = 0000000000;
   SET @V_CONT_REG_20 = 0;
   SET @V_CONT_REG_30 = 0;
   SET @V_CONT_REG_40 = 0;
   SET @V_CONT_REG_50 = 0;
   SET @V_CONT_REG_60 = 0;

   /* busca o codigo do imposto ipi */
   SELECT @V_IPI = CDIMPOSTOLIVRO
   FROM TPIMPOSLIVRO
   WHERE CDLIVROMAG = @P_LIVROMAG
     AND SGIMPOSTOLIVRO LIKE 'IPI';

   /* busca o codigo do imposto icms */
   SELECT @V_ICMS = CDIMPOSTOLIVRO
   FROM TPIMPOSLIVRO
   WHERE CDLIVROMAG = @P_LIVROMAG
     AND SGIMPOSTOLIVRO LIKE 'ICMS';

   /* busca o codigo do imposto ipi */
   SELECT @V_ISS = CDIMPOSTOLIVRO
   FROM TPIMPOSLIVRO
   WHERE CDLIVROMAG = @P_LIVROMAG
     AND SGIMPOSTOLIVRO LIKE 'ISS';

   SELECT @V_EMPRESA = '10'        + '|' +
                       '1,00'      + '|' +
                       LEFT(REPLACE(REPLACE(REPLACE(NRINSJURIEST,'/',''),'-',''),'.','') + REPLICATE('0',14), 14)+ '|' +
                       CONVERT(VARCHAR,@P_DTINICIAL,103)+ '|' +
                       CONVERT(VARCHAR,@P_DTFINAL,103)
     FROM INSCRESTAD
    WHERE CDEMPRESA = @P_CDEMPRESA
      AND CDINSCESTA = @P_CDINSCESTA;

   INSERT INTO ARQMAGNETICO
     (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
     (@V_CONTADOR, @V_EMPRESA, @P_NRSEQARQMAG);
   SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;


   /* REGISTRO 20 */
   DECLARE C_NOTAS CURSOR FOR (
      SELECT  '20'                         + '|' +
              ISNULL(NF.IDIMPNFPA,'')      + '|' +
              ISNULL(NF.IDSTATUS,'')       + '|' +
              ISNULL(NF.NMTIPOOPER,'')     + '|' +
              ISNULL(NF.CDSERIE,'')        + '|' +
              ISNULL(NF.NRNOTAFISC,'')     + '|' +
              ISNULL(SUBSTRING(NF.DTEMISSAO,1,19),'')      + '|' +
              ISNULL(SUBSTRING(NF.DTENTRSAID,1,19),'')     + '|' +
              ISNULL(NF.IDENTRSAIDOP,'')   + '|' +
              ISNULL(NF.CDFISCOPERNF,'')   + '|' +
              ''                           + '|' +
              ''                           + '|' +
              ISNULL(NF.NRINSJURCLIE,'')   + '|' +
              ISNULL(NF.NMRAZSOCCLIE,'')   + '|' +
              ISNULL(NF.DSENDECLIE,'')     + '|' +
              ISNULL(NF.ZERO,'')           + '|' +
              ISNULL(NF.DSCOMPENDCLI,'')   + '|' +
              ISNULL(NF.NMBAIRCLIE,'')     + '|' +
              ISNULL(NF.NMMUNICIPIO,'')    + '|' +
              ISNULL(NF.SGESTADO,'')       + '|' +
              ISNULL(NF.NRCEPCLIE,'')      + '|' +
              ''                           + '|' +
              ISNULL(NF.NRTELECLIE,'')     + '|' +
              ISNULL(NF.NRINSEST,''),
              NF.CDLISTA, NF.CDFILIAL, NF.NRLANCTONF, NF.NRNOTAFISC
      FROM(SELECT CASE N.IDIMPNFPA WHEN 'S' THEN 'R' ELSE 'I'END AS IDIMPNFPA,
                  CASE IDSTATUS WHEN 'C' THEN 'CANCEL' ELSE '' END AS IDSTATUS,
                  SUBSTRING(NMTIPOOPER,1,60)                       AS NMTIPOOPER,
                  CASE N.IDENTRSAIDOP WHEN 'S' THEN ( CASE N.CDSERIE WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIE,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIE,1,1) END ) END ) ELSE ( CASE N.CDSERIEENTR WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIEENTR,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIEENTR,1,1) END ) END ) END AS CDSERIE,
                  NRNOTAFISC                                        AS NRNOTAFISC,
                  CONVERT(VARCHAR, N.DTEMISSAO , 103)+' '+CONVERT(CHAR, N.DTEMISSAO,8) AS DTEMISSAO,
                  CONVERT(VARCHAR, N.DTENTRSAID , 103)+' '+CONVERT(CHAR, N.DTENTRSAID,8)  AS DTENTRSAID,
                  CASE N.IDENTRSAIDOP WHEN 'E' THEN '0' ELSE '1' END AS IDENTRSAIDOP,
                  I.CDFISCOPERNF                                     AS CDFISCOPERNF,
                  REPLACE(REPLACE(REPLACE(NRINSJURCLIE,'-',''),'/',''),'.','')  AS NRINSJURCLIE,
                  SUBSTRING(C.NMRAZSOCCLIE,1,60)                                                    AS NMRAZSOCCLIE,
                  SUBSTRING(DSENDECLIE,1,60)                                                        AS DSENDECLIE,
                  '0'                                                                            AS ZERO,
                  DSCOMPENDCLI                                                                   AS DSCOMPENDCLI,
                  NMBAIRCLIE                                                                     AS NMBAIRCLIE,
                  SUBSTRING(ISNULL(M.NMMUNICIPIO,'EXTERIOR'),1,60)                               AS NMMUNICIPIO,
                  ISNULL(E.SGESTADO,'EX')                                                        AS SGESTADO,
                  REPLACE(NRCEPCLIE,'-','')                                                      AS NRCEPCLIE,
                  REPLACE(REPLACE(REPLACE(REPLACE(E.NRTELECLIE,'(',''),')',''),'-',''),' ','')   AS NRTELECLIE,
                  REPLACE(REPLACE(REPLACE(C.NRINSESTCLIE,'-',''),'/',''),'.','')                 AS NRINSEST,
                  L.CDLISTA, N.CDFILIAL, N.NRLANCTONF
           FROM NOTAFISCAL N, TIPOOPERAC T, IMPOSTONF I,
                CLIENTE C, ENDECLIE E, MUNICIPIO M, LISTA L
           WHERE N.CDFILIAL+N.NRLANCTONF = L.CDLISTA
             AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
             AND N.CDTIPOOPER = T.CDTIPOOPER
             AND N.CDFILIAL = I.CDFILIAL
             AND N.NRLANCTONF = I.NRLANCTONF
             AND I.CDIMPOSTO = @V_ICMS
             AND N.CDCLIENTE = C.CDCLIENTE
             AND C.CDCLIENTE = E.CDCLIENTE
             AND IDTPENDECLIE = 'P'
             AND N.IDORIGDESTNF = 'C'
             AND E.CDPAIS = M.CDPAIS
             AND E.SGESTADO = M.SGESTADO
             AND E.CDMUNICIPIO = M.CDMUNICIPIO
             AND L.NRLISTA = @P_NRLISTA
           GROUP BY CASE N.IDIMPNFPA WHEN 'S' THEN 'R' ELSE 'I'END,
                    CASE IDSTATUS WHEN 'C' THEN 'CANCEL' ELSE '' END,
                    SUBSTRING(NMTIPOOPER,1,60),
                    CASE N.IDENTRSAIDOP WHEN 'S' THEN ( CASE N.CDSERIE WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIE,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIE,1,1) END ) END ) ELSE ( CASE N.CDSERIEENTR WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIEENTR,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIEENTR,1,1) END ) END ) END,
                    NRNOTAFISC,
                    CONVERT(VARCHAR, N.DTEMISSAO , 103)+' '+CONVERT(CHAR, N.DTEMISSAO,8),
                    CONVERT(VARCHAR, N.DTENTRSAID , 103)+' '+CONVERT(CHAR, N.DTENTRSAID,8),
                    CASE N.IDENTRSAIDOP WHEN 'E' THEN '0' ELSE '1'END,
                    I.CDFISCOPERNF, REPLACE(REPLACE(REPLACE(NRINSJURCLIE,'-',''),'/',''),'.',''),
                    SUBSTRING(C.NMRAZSOCCLIE,1,60), SUBSTRING(DSENDECLIE,1,60),
                    DSCOMPENDCLI, NMBAIRCLIE, SUBSTRING(ISNULL(M.NMMUNICIPIO,'EXTERIOR'),1,60),
                    ISNULL(E.SGESTADO,'EX'), REPLACE(NRCEPCLIE,'-',''),
                    REPLACE(REPLACE(REPLACE(REPLACE(E.NRTELECLIE,'(',''),')',''),'-',''),' ','') ,
                    REPLACE(REPLACE(REPLACE(C.NRINSESTCLIE,'-',''),'/',''),'.',''),
                    L.CDLISTA, N.CDFILIAL, N.NRLANCTONF
           UNION ALL
           SELECT CASE N.IDIMPNFPA WHEN 'S' THEN 'R' ELSE 'I'END  AS IDIMPNFPA,
                  CASE IDSTATUS WHEN 'C' THEN 'CANCEL' ELSE '' END AS IDSTATUS,
                  SUBSTRING(NMTIPOOPER,1,60)           AS NMTIPOOPER,
                  CASE N.IDENTRSAIDOP WHEN 'S' THEN ( CASE N.CDSERIE WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIE,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIE,1,1) END ) END ) ELSE ( CASE N.CDSERIEENTR WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIEENTR,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIEENTR,1,1) END ) END ) END AS CDSERIE,
                  NRNOTAFISC  AS NRNOTAFISC,
                  CONVERT(VARCHAR, N.DTEMISSAO , 103)+' '+CONVERT(CHAR, N.DTEMISSAO,8) AS DTEMISSAO,
                  CONVERT(VARCHAR, N.DTENTRSAID , 103)+' '+CONVERT(CHAR, N.DTENTRSAID,8) AS DTENTRSAID,
                  CASE N.IDENTRSAIDOP WHEN 'E' THEN '0' ELSE '1'END AS IDENTRSAIDOP,
                  I.CDFISCOPERNF  AS CDFISCOPERNF,
                  REPLACE(REPLACE(REPLACE(NRINSJURFORN,'-',''),'/',''),'.','') AS NRINSJURCLIE,
                  SUBSTRING(F.NMRAZSOCFORN,1,60)  AS NMRAZSOCCLIE,
                  SUBSTRING(DSENDEFORN,1,60)      AS DSENDECLIE,
                  '0'                             AS ZERO,
                  DSCOMPENDFOR                    AS DSCOMPENDCLI,
                  NMBAIRFORN                      AS NMBAIRCLIE,
                  SUBSTRING(ISNULL(M.NMMUNICIPIO,'EXTERIOR'),1,60) AS NMMUNICIPIO,
                  ISNULL(E.SGESTADO,'EX')  AS SGESTADO,
                  REPLACE(NRCEPFORN,'-','')AS NRCEPCLIE,
                  REPLACE(REPLACE(REPLACE(REPLACE(E.NRTELEFORN,'(',''),')',''),'-',''),' ','') AS NRTELECLIE,
                  REPLACE(REPLACE(REPLACE(F.NRINSESTFORN,'-',''),'/',''),'.','')               AS NRINSEST,
                  L.CDLISTA, N.CDFILIAL, N.NRLANCTONF
           FROM NOTAFISCAL N, TIPOOPERAC T, IMPOSTONF I,
                FORNECEDOR F, ENDEFORN E, MUNICIPIO M, LISTA L
           WHERE N.CDFILIAL+N.NRLANCTONF = L.CDLISTA
             AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
             AND N.CDTIPOOPER = T.CDTIPOOPER
             AND N.CDFILIAL = I.CDFILIAL
             AND N.NRLANCTONF = I.NRLANCTONF
             AND I.CDIMPOSTO = @V_ICMS
             AND N.CDFORNECED = F.CDFORNECED
             AND F.CDFORNECED = E.CDFORNECED
             AND IDTPENDEFORN = 'P'
             AND N.IDORIGDESTNF = 'F'
             AND E.CDPAIS = M.CDPAIS
             AND E.SGESTADO = M.SGESTADO
             AND E.CDMUNICIPIO = M.CDMUNICIPIO
             AND L.NRLISTA = @P_NRLISTA
           GROUP BY CASE N.IDIMPNFPA WHEN 'S' THEN 'R' ELSE 'I'END ,
                    CASE IDSTATUS WHEN 'C' THEN 'CANCEL' ELSE '' END,
                    SUBSTRING(NMTIPOOPER,1,60),
                    CASE N.IDENTRSAIDOP WHEN 'S' THEN ( CASE N.CDSERIE WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIE,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIE,1,1) END ) END ) ELSE ( CASE N.CDSERIEENTR WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIEENTR,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIEENTR,1,1) END ) END ) END,
                    NRNOTAFISC,
                    CONVERT(VARCHAR, N.DTEMISSAO , 103)+' '+CONVERT(CHAR, N.DTEMISSAO,8),
                    CONVERT(VARCHAR, N.DTENTRSAID , 103)+' '+CONVERT(CHAR, N.DTENTRSAID,8),
                    CASE N.IDENTRSAIDOP WHEN 'E' THEN '0' ELSE '1'END,
                    I.CDFISCOPERNF, REPLACE(REPLACE(REPLACE(NRINSESTFORN,'-',''),'/',''),'.',''),
                    REPLACE(REPLACE(REPLACE(NRINSJURFORN,'-',''),'/',''),'.',''),
                    SUBSTRING(F.NMRAZSOCFORN,1,60), SUBSTRING(DSENDEFORN,1,60),
                    DSCOMPENDFOR, NMBAIRFORN, SUBSTRING(ISNULL(M.NMMUNICIPIO,'EXTERIOR'),1,60),
                    ISNULL(E.SGESTADO,'EX'), REPLACE(NRCEPFORN,'-',''),
                    REPLACE(REPLACE(REPLACE(REPLACE(E.NRTELEFORN,'(',''),')',''),'-',''),' ','') ,
                    REPLACE(REPLACE(REPLACE(F.NRINSESTFORN,'-',''),'/',''),'.',''),
                    L.CDLISTA, N.CDFILIAL, N.NRLANCTONF
           UNION ALL
           SELECT CASE N.IDIMPNFPA WHEN 'S' THEN 'R' ELSE 'I'END  AS IDIMPNFPA,
                  CASE IDSTATUS WHEN 'C' THEN 'CANCEL' ELSE '' END AS IDSTATUS,
                  SUBSTRING(NMTIPOOPER,1,60)           AS NMTIPOOPER,
                  CASE N.IDENTRSAIDOP WHEN 'S' THEN ( CASE N.CDSERIE WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIE,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIE,1,1) END ) END ) ELSE ( CASE N.CDSERIEENTR WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIEENTR,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIEENTR,1,1) END ) END ) END AS CDSERIE,
                  NRNOTAFISC  AS NRNOTAFISC,
                  CONVERT(VARCHAR, N.DTEMISSAO , 103)+' '+CONVERT(CHAR, N.DTEMISSAO,8) AS DTEMISSAO,
                  CONVERT(VARCHAR, N.DTENTRSAID , 103)+' '+CONVERT(CHAR, N.DTENTRSAID,8) AS DTENTRSAID,
                  CASE N.IDENTRSAIDOP WHEN 'E' THEN '0' ELSE '1'END AS IDENTRSAIDOP,
                  I.CDFISCOPERNF  AS CDFISCOPERNF,
                  REPLACE(REPLACE(REPLACE(NRINSJURFILI,'-',''),'/',''),'.','') AS NRINSJURCLIE,
                  SUBSTRING(F.NMRAZSOCFILI,1,60)  AS NMRAZSOCCLIE,
                  SUBSTRING(DSENDEFILI,1,60)      AS DSENDECLIE,
                  '0'                             AS ZERO,
                  DSCOMPENDFIL                    AS DSCOMPENDCLI,
                  NMBAIRFILI                      AS NMBAIRCLIE,
                  SUBSTRING(ISNULL(M.NMMUNICIPIO,'EXTERIOR'),1,60) AS NMMUNICIPIO,
                  ISNULL(E.SGESTADO,'EX')  AS SGESTADO,
                  REPLACE(NRCEPFILI,'-','')AS NRCEPCLIE,
                  REPLACE(REPLACE(REPLACE(REPLACE(E.NRTELEFILI,'(',''),')',''),'-',''),' ','') AS NRTELECLIE,
                  REPLACE(REPLACE(REPLACE(F.CDINSCESTA,'-',''),'/',''),'.','')               AS NRINSEST,
                  L.CDLISTA, N.CDFILIAL, N.NRLANCTONF
           FROM NOTAFISCAL N, TIPOOPERAC T, IMPOSTONF I,
                FILIAL F, ENDEFILI E, MUNICIPIO M, LISTA L
           WHERE N.CDFILIAL+N.NRLANCTONF = L.CDLISTA
             AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
             AND N.CDTIPOOPER = T.CDTIPOOPER
             AND N.CDFILIAL = I.CDFILIAL
             AND N.NRLANCTONF = I.NRLANCTONF
             AND I.CDIMPOSTO = @V_ICMS
             AND N.CDFILIRECE = F.CDFILIAL
             AND F.CDFILIAL = E.CDFILIAL
             AND IDTPENDEFILI = 'P'
             AND N.IDORIGDESTNF = 'L'
             AND E.CDPAIS = M.CDPAIS
             AND E.SGESTADO = M.SGESTADO
             AND E.CDMUNICIPIO = M.CDMUNICIPIO
             AND L.NRLISTA = @P_NRLISTA
           GROUP BY CASE N.IDIMPNFPA WHEN 'S' THEN 'R' ELSE 'I'END ,
                    CASE IDSTATUS WHEN 'C' THEN 'CANCEL' ELSE '' END,
                    SUBSTRING(NMTIPOOPER,1,60),
                    CASE N.IDENTRSAIDOP WHEN 'S' THEN ( CASE N.CDSERIE WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIE,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIE,1,1) END ) END ) ELSE ( CASE N.CDSERIEENTR WHEN 'U' THEN '0' ELSE ( CASE SUBSTRING(N.CDSERIEENTR,1,1) WHEN '-' THEN '0' ELSE SUBSTRING(N.CDSERIEENTR,1,1) END ) END ) END,
                    NRNOTAFISC,
                    CONVERT(VARCHAR, N.DTEMISSAO , 103)+' '+CONVERT(CHAR, N.DTEMISSAO,8),
                    CONVERT(VARCHAR, N.DTENTRSAID , 103)+' '+CONVERT(CHAR, N.DTENTRSAID,8),
                    CASE N.IDENTRSAIDOP WHEN 'E' THEN '0' ELSE '1'END,
                    I.CDFISCOPERNF, REPLACE(REPLACE(REPLACE(F.CDINSCESTA,'-',''),'/',''),'.',''),
                    REPLACE(REPLACE(REPLACE(NRINSJURFILI,'-',''),'/',''),'.',''),
                    SUBSTRING(F.NMRAZSOCFILI,1,60), SUBSTRING(DSENDEFILI,1,60),
                    DSCOMPENDFIL, NMBAIRFILI, SUBSTRING(ISNULL(M.NMMUNICIPIO,'EXTERIOR'),1,60),
                    ISNULL(E.SGESTADO,'EX'), REPLACE(NRCEPFILI,'-',''),
                    REPLACE(REPLACE(REPLACE(REPLACE(E.NRTELEFILI,'(',''),')',''),'-',''),' ','') ,
                    REPLACE(REPLACE(REPLACE(F.CDINSCESTA,'-',''),'/',''),'.',''),
                    L.CDLISTA, N.CDFILIAL, N.NRLANCTONF)NF)

   OPEN C_NOTAS;
   FETCH NEXT FROM C_NOTAS INTO @C_NOTAS_ARQUIVO, @C_NOTAS_CDLISTA,
                                @C_NOTAS_CDFILIAL, @C_NOTAS_NRLANCTONF, @C_NOTAS_NRNOTAFISC;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_CONT_REG_20 = ISNULL(@V_CONT_REG_20,0)+1;
      INSERT INTO ARQMAGNETICO
        (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
      VALUES
        (@V_CONTADOR, @C_NOTAS_ARQUIVO, @P_NRSEQARQMAG);
      SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;

      /* REGISTRO 30 */
      DECLARE C_ITENS_NOTAS CURSOR FOR (SELECT ('30'                               + '|' +
                                                ISNULL(P.CDARVPROD,'')                        + '|' +
                                                ISNULL(SUBSTRING(P.NMPRODUTO,1,60),'')        + '|' +
                                                ISNULL(P.CDPRODNCM,'')                        + '|' +
                                                ISNULL(P.SGUNIDADE,'')                        + '|' +
                                                ISNULL(RIGHT(REPLICATE('0',12)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(12,4), QTITEMPROD)),'.',','),12),'0,00')           + '|' +
                                                ISNULL(RIGHT(REPLICATE('0',16)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(16,4), VRUNITITEM)),'.',','),16),'0,00')           + '|' +
                                                ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), VRTOTAITEM)),'.',','),15),'0,00')           + '|' +
                                                ISNULL(CDSITUTRIBPR,'')           + '|' +
                                                ISNULL(RIGHT(REPLICATE('0',5)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(5,2), VRALIQITEM)),'.',','),5),'0,00')          + '|' +
                                                ISNULL(RIGHT(REPLICATE('0',5)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(5,2), TEKNISA.VALOR_IMPOSTO_ITEM(IT.CDFILIAL, IT.NRLANCTONF, IT.NRSEQITPROD, ISNULL(@V_IPI,0), 'A', IT.CDFISCALIT, IT.NRITPROIMPOS))),'.',','),5),'0,00') + '|' +
                                                ISNULL(RIGHT(REPLICATE('0',5)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(5,2), TEKNISA.VALOR_IMPOSTO_ITEM(IT.CDFILIAL, IT.NRLANCTONF, IT.NRSEQITPROD, ISNULL(@V_IPI,0), 'I', IT.CDFISCALIT, IT.NRITPROIMPOS))),'.',','),5),'0,00')) AS ARQUIVO
                                        FROM ITEMPRODUTO I, PRODUTO P, ITEMPROIMPOS IT
                                        WHERE I.CDFILIAL = @C_NOTAS_CDFILIAL
                                          AND I.NRLANCTONF = @C_NOTAS_NRLANCTONF
                                          AND P.CDPRODUTO   = I.CDPRODUTO
                                          AND I.CDFILIAL    = IT.CDFILIAL
                                          AND I.NRLANCTONF  = IT.NRLANCTONF
                                          AND I.NRSEQITPROD = IT.NRSEQITPROD
                                          AND CDIMPOSTO     = @V_ICMS
                                          AND IT.NRITPROIMPOS = '1')
      OPEN C_ITENS_NOTAS;
      FETCH NEXT FROM C_ITENS_NOTAS INTO @C_CORPONF_DADOS30;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         /* contador do registro 30 */
         SET @V_CONT_REG_30 = ISNULL(@V_CONT_REG_30,0)+1;
         INSERT INTO ARQMAGNETICO
           (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
         VALUES
           (@V_CONTADOR, @C_CORPONF_DADOS30, @P_NRSEQARQMAG);
         SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;

         FETCH NEXT FROM C_ITENS_NOTAS INTO @C_CORPONF_DADOS30;

      END;
      CLOSE C_ITENS_NOTAS;
      DEALLOCATE C_ITENS_NOTAS;

      /* REGISTRO 40 */

      SELECT @V_IDFRETE = ISNULL(EN.IDENCARGO,'')
      FROM RELACENCARGO E, ENCARGO EN
      WHERE E.CDENCARGO = EN.CDENCARGO AND
            E.IDENCARGODOS LIKE '%FRET%';

      SELECT @V_IDSEGUR = ISNULL(EN.IDENCARGO,'')
      FROM RELACENCARGO E, ENCARGO EN
      WHERE E.CDENCARGO = EN.CDENCARGO AND
            E.IDENCARGODOS LIKE '%SEGU%';

      SELECT @V_IDOUTROS = ISNULL(EN.IDENCARGO,'')
      FROM RELACENCARGO E, ENCARGO EN
      WHERE E.CDENCARGO = EN.CDENCARGO AND
            E.IDENCARGODOS LIKE '%OUTR%';

      SELECT @V_IDDESCO = ISNULL(EN.IDENCARGO,'')
      FROM RELACENCARGO E, ENCARGO EN
      WHERE E.CDENCARGO = EN.CDENCARGO AND
            E.IDENCARGODOS LIKE '%DESC%';

      SELECT @V_CDIMPOSTRIB = ISNULL(CDIMPOSTRIB,'')
      FROM IMPOSTO
      WHERE CDIMPOSTO = @V_ICMS;

      SELECT @V_IDFRETE = ISNULL(IDENCARGO, '')
        FROM ENCARGO E, ITEMENCARGO I
       WHERE E.CDENCARGO = I.CDENCARGO
         AND I.CDFILIAL = @C_NOTAS_CDFILIAL
         AND I.NRLANCTONF = @C_NOTAS_NRLANCTONF
         AND VRITEMENCA > 0;

      SELECT @V_VRDESCONTO = CONVERT(DOUBLE PRECISION, REPLACE((ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(VRDESCITEM))),'.',','),15),'0,00')),',','.'))
        FROM ITEMPRODUTO
       WHERE CDFILIAL = @C_NOTAS_CDFILIAL
         AND NRLANCTONF = @C_NOTAS_NRLANCTONF;
      
      SELECT @V_DADOS_40 = '40' + '|' +
                           VALOR1+ '|' +
                           VALOR2+ '|' +
                           VALOR3+ '|' +
                           VALOR4+ '|' +
                           ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), (CONVERT(DOUBLE PRECISION, REPLACE(VALOR5, ',','.'))-TEKNISA.VALOR_ENCARGO(@C_NOTAS_CDFILIAL, @C_NOTAS_NRLANCTONF, @V_IDFRETE,NULL)+@V_VRDESCONTO))),'.',','),15),'0,00')  + '|' +
                           ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), (TEKNISA.VALOR_ENCARGO(@C_NOTAS_CDFILIAL, @C_NOTAS_NRLANCTONF, @V_IDFRETE,NULL)))),'.',','),15),'0,00')  + '|' +
                           VALOR7+ '|' +
                           ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), (CASE CONVERT(DOUBLE PRECISION, REPLACE(VALOR8, ',','.')) WHEN 0 THEN @V_VRDESCONTO ELSE 0 END))),'.',','),15),'0,00') + '|' +
                           VALOR9+ '|' +
                           VALOR10+ '|' +
                           VALOR11+ '|' +
                           VALOR12+ '|' +
                           VALOR13+ '|' +
                           VALOR14+ '|'

      FROM ( SELECT ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(VRBASECALCIT))),'.',','),15),'0,00') AS VALOR1,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(VRIMPOSTOIT))),'.',','),15),'0,00') AS VALOR2,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_CDIMPOSTRIB,''), 'B', NULL)))),'.',','),15),'0,00') AS VALOR3,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_CDIMPOSTRIB,''), 'I', NULL)))),'.',','),15),'0,00') AS VALOR4,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(VRCONTITIMP))),'.',','),15),'0,00') AS VALOR5,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_ENCARGO(CDFILIAL, NRLANCTONF, ISNULL(@V_IDFRETE,''),NULL)))),'.',','),15),'0,00') AS VALOR6,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_ENCARGO(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_IDSEGUR,''),NULL)))),'.',','),15),'0,00') AS VALOR7,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_ENCARGO(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_IDDESCO,''),NULL)))),'.',','),15),'0,00') AS VALOR8,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_IPI,''), 'I', NULL)))),'.',','),15),'0,00') AS VALOR9,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_ENCARGO(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_IDOUTROS,''),NULL)))),'.',','),15),'0,00') AS VALOR10,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(VRCONTITIMP))),'.',','),15),'0,00') AS VALOR11,
                    '0,00' AS VALOR12,
                    ISNULL(RIGHT(REPLICATE('0',5)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(5,2), SUM(TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_ISS,''), 'A',NULL)))),'.',','),5),'0,00') AS VALOR13,
                    ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,2), SUM(TEKNISA.VALOR_IMPOSTO_NF(I.CDFILIAL, I.NRLANCTONF, ISNULL(@V_ISS,''), 'I',NULL)))),'.',','),15),'0,00')  AS VALOR14
               FROM ITEMPROIMPOS I
              WHERE I.CDFILIAL = @C_NOTAS_CDFILIAL
                AND I.NRLANCTONF = @C_NOTAS_NRLANCTONF
                AND I.CDIMPOSTO = @V_ICMS) A;

      /* contador do registro 40 */
      SET @V_CONT_REG_40 = ISNULL(@V_CONT_REG_40,0)+1;
      INSERT INTO ARQMAGNETICO
        (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
      VALUES
        (@V_CONTADOR, @V_DADOS_40, @P_NRSEQARQMAG);
      SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;

      /* REGISTRO 50 */
      SELECT @V_DADOS_50 = ('50'        + '|' +
                            ISNULL(CASE N.IDPGTOFRETE WHEN '1' THEN '0' ELSE '1' END,'')                  + '|' +
                            ISNULL(REPLACE(REPLACE(REPLACE(T.NRINSJURTRAN,'.',''),'/',''),'-',''),'')     + '|' +
                            ISNULL(SUBSTRING(T.NMRAZSOCTRAN,1,60),'')        + '|' +
                            ISNULL(T.NRINSESTTRAN,'')                        + '|' +
                            ISNULL(T.DSENDETRAN,'')                          + '|' +
                            ISNULL(SUBSTRING(M.NMMUNICIPIO,1,60),'')         + '|' +
                            ISNULL(M.SGESTADO,'')                            + '|' +
                            ISNULL(N.NRPLACAVEIC,'')                         + '|' +
                            ''                                    + '|' +
                            ISNULL(SUBSTRING(DSQTDEVOLU,1,15),'')            + '|' +
                            ISNULL(SUBSTRING(DSESPECVOLU,1,60),'')           + '|' +
                            ISNULL(SUBSTRING(DSMARCAVOLU,1,60),'')           + '|' +
                            ISNULL(SUBSTRING(DSNUMEVOLU,1,60),'')            + '|' +
                            ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,3), VRPLIQUVOLU)),'.',','),15),'0,00')     + '|' +
                            ISNULL(RIGHT(REPLICATE('0',15)+REPLACE(CONVERT(VARCHAR,CONVERT(NUMERIC(15,3), VRPBRUTOVOLU)),'.',','),15),'0,00')    + '|' )
      FROM NOTAFISCAL N, TRANSPORT T, MUNICIPIO M
      WHERE N.CDFILIAL = @C_NOTAS_CDFILIAL
        AND N.NRLANCTONF = @C_NOTAS_NRLANCTONF
        AND N.IDTPIJURTRAN = T.IDTPIJURTRAN
        AND N.NRINSJURTRAN = T.NRINSJURTRAN
        AND T.CDPAIS = M.CDPAIS
        AND T.SGESTADO = M.SGESTADO
        AND T.CDMUNICIPIO = M.CDMUNICIPIO;


      IF @V_DADOS_50 IS NULL BEGIN
         SET @V_DADOS_50 = '50'  + '|' + '1'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|'
                                 + '|';
         /* contador do registro 50 */
         SET @V_CONT_REG_50 = ISNULL(@V_CONT_REG_50,0)+1;
         INSERT INTO ARQMAGNETICO
           (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
         VALUES
           (@V_CONTADOR, @V_DADOS_50, @P_NRSEQARQMAG);
         SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;
      END
      ELSE BEGIN
         /* contador do registro 50 */
         SET @V_CONT_REG_50 = ISNULL(@V_CONT_REG_50,0)+1;
         INSERT INTO ARQMAGNETICO
           (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
         VALUES
           (@V_CONTADOR, @V_DADOS_50, @P_NRSEQARQMAG);
         SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;
      END;


   /* REGISTRO 60 */
      SET @V_CONT_REG_60 = ISNULL(@V_CONT_REG_60,0)+1;
      INSERT INTO ARQMAGNETICO
        (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
      VALUES
        (@V_CONTADOR, '60'+ '|' + ''+ '|' +''+ '|' + '|' , @P_NRSEQARQMAG);
      SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;

      UPDATE NOTAFISCAL
      SET IDIMPNFPA = 'S'
      WHERE CDFILIAL = @C_NOTAS_CDFILIAL
        AND NRLANCTONF = @C_NOTAS_NRLANCTONF;

      FETCH NEXT FROM C_NOTAS INTO @C_NOTAS_ARQUIVO, @C_NOTAS_CDLISTA,
                                @C_NOTAS_CDFILIAL, @C_NOTAS_NRLANCTONF, @C_NOTAS_NRNOTAFISC;

   END;
   CLOSE C_NOTAS;
   DEALLOCATE C_NOTAS;

   SET @V_DADOS_90 =  '90'                                                            + '|' +
                      RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR, ISNULL(@V_CONT_REG_20,0)), 5)  + '|' +
                      RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR, ISNULL(@V_CONT_REG_30,0)), 5)  + '|' +
                      RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR, ISNULL(@V_CONT_REG_40,0)), 5)  + '|' +
                      RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR, ISNULL(@V_CONT_REG_50,0)), 5)  + '|' +
                      RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR, ISNULL(@V_CONT_REG_60,0)), 5);

   /* REGISTRO 90 */

   INSERT INTO ARQMAGNETICO
     (NRORDREGARQ, DSREGARQMAG, NRSEQARQMAG)
   VALUES
     (@V_CONTADOR, @V_DADOS_90 , @P_NRSEQARQMAG);
   SET @V_CONTADOR = ISNULL(@V_CONTADOR,0)+1;
END
GO


-- VERSAO --
EXEC ATUVEROBJ 'NF_PAULISTA','5.05.025';
GO

